package com.example.civilizedcity.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.civilizedcity.common.BaseController;
import com.example.civilizedcity.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.example.civilizedcity.entity.TaFeedback;
import com.example.civilizedcity.service.TaFeedbackService;

 /**
 * 反馈表;(ta_feedback)表控制层
 * @author : http://njyunzhi.com
 * @date : 2023-1-30
 */
@Api(tags = "反馈表对象功能接口")
@RestController
@RequestMapping("/")
public class TaFeedbackController extends BaseController {
    
    @Autowired
    private TaFeedbackService taFeedbackService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param feedbackId 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taFeedback/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return ResponseBean.success(taFeedbackService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/taFeedback")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<TaFeedback> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<TaFeedback> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<TaFeedback> result = taFeedbackService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taFeedback 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/taFeedback")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaFeedback taFeedback) throws Exception {
        taFeedbackService.save(taFeedback);
        return ResponseBean.success(taFeedback);
    }
    
    /** 
     * 更新数据
     *
     * @param taFeedback 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/taFeedback/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaFeedback taFeedback,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        taFeedbackService.updateById(taFeedback);
        return ResponseBean.success(taFeedback);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param feedbackId 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taFeedback/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id){
        taFeedbackService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}